@@ -10,12 +10,13 @@
 #
 # MIT License
 #
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the ""Software""), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation files
+# (the ""Software""), to deal in the Software without restriction,
+# including without limitation the rights to use, copy, modify, merge,
+# publish, distribute, sublicense, and/or sell copies of the Software,
+# and to permit persons to whom the Software is furnished to do so,
+# subject to the following conditions:
 #
 # The above copyright notice and this permission notice shall be included in
 # all copies or substantial portions of the Software.
@@ -55,7 +56,8 @@ utils.add_log_handler(
     constants.LOG_FILE_LEVEL,
     constants.LOG_FILE_FORMAT)
 
-logger.info('---------- {} {} ----------'.format(os.path.basename(sys.argv[0]), ' '.join(sys.argv[1:])))
+logger.info('---------- {} {} ----------'.format(os.path.basename(sys.argv[0]),
+                                                 ' '.join(sys.argv[1:])))
 
 # ----------------------------------------------------------------------
 # Set up command line parser and dispatch commands.
@@ -94,7 +96,9 @@ def main():
 
     # Get the first positional argument.
 
-    pos_args = [(i, arg) for i, arg in enumerate(sys.argv[1:]) if not arg.startswith('-')]
+    pos_args = [(i, arg)
+                for i, arg in enumerate(sys.argv[1:])
+                if not arg.startswith('-')]
     first_pos_arg_index, first_pos_arg = pos_args[0] if len(pos_args) != 0 else (None, None)
     logger.debug(f'First positional argument: {first_pos_arg}')
 
@@ -303,10 +307,10 @@ def main():
         sys.exit(1)
 
     except utils.MalformedPackagesDotYAMLException as e:
-        msg = ("There is no '{}' available for the model package '{}' which may be under maintenance now.\n"
-               "Please try again later.")
-        utils.print_error(msg, e.args[0], e.args[1])
-        if not args.quiet:  # Suggest check if any models available, since specified model not available
+        msg = (f"No '{e.args[0]}' available for the package '{e.args[1]}'.")
+        utils.print_error(msg)
+        # Suggest AVAILABLE since specified model is not available.
+        if not args.quiet:
             utils.print_commands_suggestions_on_stderr('available')
         sys.exit(1)
 
