@@ -44,6 +44,7 @@ import textwrap
 import urllib.request
 import yaml
 from mlhub.pkg import generalkey
+import mlhub.constants as constants
 
 from distutils.version import StrictVersion
 from mlhub.constants import (
@@ -774,7 +775,7 @@ def configure_model(args):
 
     if not args.model:
 
-        # Configure MLHUB per se.
+        # Configure MLHUB itself.
         # Includes bash completion and system pre-requisites
 
         if distro.id() in ["debian", "ubuntu"]:
@@ -821,9 +822,20 @@ def configure_model(args):
 
         private_out = []
 
-        for item in require_info.items():
-            elements = [x.strip() for x in item[1].split(',')]
-            private_out.append([item[0], elements])
+        # if the private entry is :
+        # private: key*, location
+
+        if isinstance(require_info, str):
+            private_out = [x.strip() for x in require_info.split(',')]
+
+        # if the private entry is :
+        # private:
+        #   Azure Speech: key*, location
+
+        else:
+            for item in require_info.items():
+                elements = [x.strip() for x in item[1].split(',')]
+                private_out.append([item[0], elements])
 
         private_json_path = os.path.join(pkg_dir, "private.json")
 
@@ -1240,3 +1252,16 @@ def remove_model(args):
             if model is None and not args.quiet:
                 print("\nMLHub has not been removed.")
                 utils.print_next_step("uninstall")
+
+
+# ------------------------------------------------------------------------
+# Version
+# ------------------------------------------------------------------------
+
+
+def check_version(args):
+    model = args.model
+    if model:
+        print(model, "version", utils.get_version(model))
+    else:
+        print(constants.APP, "version", utils.get_version())
